@@ -1,7 +1,7 @@
 import discord, asyncio, aiohttp
 from discord.ext import commands
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 
 class Cli(commands.Bot):
     def __init__(self, channel_id : int, **kwargs):
@@ -15,7 +15,7 @@ class Cli(commands.Bot):
                 if message.author == self.user:
                     return
                 print(f"> {message.author} - {message.content}")
-                send_what = input("[ Admin ] Send a message: ")
+                send_message = input("[ Admin ] Send a message: ")
                 await message.channel.send(send_message)
         await self.process_commands(message)
                 
